# Remind
![Py Badge](https://img.shields.io/badge/Python-3.4%2B-blue) ![License badge](https://img.shields.io/pypi/l/termremind) ![Badge](https://img.shields.io/badge/Mom%20made-pizza%20rolls-orange) 
## Terminal reminder tool
### PIP Install:
* `pip3 install termremind`
* For any `*nix` (MacOS included, I think?):
    * You need to make sure that `~/.local/bin/` is in your `$PATH`. 
        * This is usually set by `~/.bashrc` or `~/.zshrc` depending on your shell.
        * You can check by issuing `echo $PATH`, and looking for that entry between `:`'s.
* For Windows:
    * As long as you installed Python with Pip, this should be a non-issue
* Done!
### Source-install:
* `git clone https://github.com/SomethingGeneric/Remind`
* `cd Remind && pip3 install .`
* You need to make sure that `~/.local/bin/` is in your `$PATH`. 
    * This is usually set by `.bashrc` or `.zshrc` depending on your shell.
    * You can check by issuing `echo $PATH`, and looking for that entry between `:`'s.
* Done!
### Usage:
See `remind/main.py` (or `remind help` once it's installed)
